#
# spec file for package trojita
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         X_display         ":98"
Name:           trojita
Version:        0.7
Release:        1.1
Summary:        Qt5 IMAP e-mail client
License:        (GPL-2.0 or GPL-3.0) and BSD-3-Clause and LGPL-2.0 and (LGPL-2.1 or GPL-3.0) and LGPL-2.1+ and GPL-2.0
Group:          Productivity/Networking/Email/Clients
# Almost everything: dual-licensed under the GPLv2 or GPLv3
# (with KDE e.V. provision for relicensing)
# src/XtConnect: BSD
# src/Imap/Parser/3rdparty/kcodecs.*: LGPLv2
# Nokia imports: LGPLv2.1 or GPLv3
# src/Imap/Parser/3rdparty/rfccodecs.cpp: LGPLv2+
# src/qwwsmtpclient/: GPLv2
Url:            http://trojita.flaska.net/
Source:         http://sourceforge.net/projects/trojita/files/src/%{name}-%{version}.tar.xz
Source1:        http://sourceforge.net/projects/trojita/files/src/%{name}-%{version}.tar.xz.asc
BuildRequires:  cmake >= 2.8.7
BuildRequires:  git
BuildRequires:  gpgmepp5-devel
BuildRequires:  libqt5-linguist-devel >= 5.2.0
BuildRequires:  libqt5-sql-sqlite
BuildRequires:  pkgconfig
BuildRequires:  qtkeychain-qt5-devel
BuildRequires:  ragel
BuildRequires:  update-desktop-files
BuildRequires:  xorg-x11-Xvfb
BuildRequires:  pkgconfig(Qt5Core) >= 5.2.0
BuildRequires:  pkgconfig(Qt5DBus) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Gui) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Network) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Sql) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Svg) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Test) >= 5.2.0
BuildRequires:  pkgconfig(Qt5WebKitWidgets) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Widgets) >= 5.2.0
BuildRequires:  pkgconfig(xkeyboard-config)
BuildRequires:  pkgconfig(zlib)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Trojita is a Qt IMAP e-mail client which:
  * Enables you to access your mail anytime, anywhere.
  * Does not slow you down. If we can improve the productivity of an e-mail user, we better do.
  * Respects open standards and facilitates modern technologies. We value the vendor-neutrality that IMAP provides and are committed to be as interoperable as possible.
  * Is efficient — be it at conserving the network bandwidth, keeping memory use at a reasonable level or not hogging the system's CPU.
  * Can be used on many platforms. One UI is not enough for everyone, but our IMAP core works fine on anything from desktop computers to cell phones and big ERP systems.
  * Plays well with the rest of the ecosystem. We don't like reinventing wheels, but when the existing wheels quite don't fit the tracks, we're not afraid of making them work.

%prep
%setup -q

%build
export CXXFLAGS="%{optflags} -fPIC"
export LDFLAGS="-pie"
%cmake \
	-DWITH_TESTS=ON \
	-DWITH_QT5=ON \
	-DWITH_ZLIB=ON \
	-DWITH_RAGEL=OFF \
	-DWITH_SHARED_PLUGINS=ON
make %{?_smp_mflags}

%install
cd build
make %{?_smp_mflags} DESTDIR=%{buildroot} install
%suse_update_desktop_file %{buildroot}/%{_datadir}/applications/trojita.desktop

%check
export LD_LIBRARY_PATH="${LD_LIBRARY_PATH}${LD_LIBRARY_PATH:+:}%{buildroot}%{_libdir}"
export DISPLAY=%{X_display}
Xvfb %{X_display} &
trap "kill $! || true" EXIT
cd build
ctest --output-on-failure

%files
%defattr(-,root,root)
%doc LICENSE README
%{_libdir}/libtrojita_plugins.so
%dir %{_libdir}/trojita
%{_libdir}/trojita/trojita_plugin_QtKeychainPasswordPlugin.so
%{_bindir}/trojita
%{_bindir}/be.contacts
%{_datadir}/applications/trojita.desktop
%dir %{_datadir}/icons/hicolor
%dir %{_datadir}/icons/hicolor/*
%dir %{_datadir}/icons/hicolor/*/apps
%{_datadir}/icons/hicolor/32x32/apps/trojita.png
%{_datadir}/icons/hicolor/scalable/apps/trojita.svg
%dir %{_datadir}/trojita
%dir %{_datadir}/trojita/locale
%{_datadir}/trojita/locale/trojita_common_*.qm
%dir %{_datadir}/appdata
%{_datadir}/appdata/trojita.appdata.xml

%changelog
* Fri Jul 15 2016 hrvoje.senjan@gmail.com
- Disable ragel to fix Tumbleweed compilation
- Enable qtkeychain-qt5-devel and gpgmepp5-devel BuildRequires
* Tue Jun 21 2016 tchvatal@suse.com
- Version update to 0.7:
  * various bugfixes
  * Support for encryption
* Wed Jun  1 2016 tchvatal@suse.com
- Version update to latest release 0.6, merged all patches:
  * fix-missing-includes.patch
  * fix-qt5_5-test-regression.patch
  * libqt5_6.patch
* Wed Jun  1 2016 tchvatal@suse.com
- Add patch to build on qt 5.6:
  * libqt5_6.patch
* Thu Dec  3 2015 rpm@fthiessen.de
- Added fix-missing-includes.patch for fixing missing includes
  when using qt5.
- Added fix-qt5_5-test-regression.patch to circumvent a regression
  in qt5 5.5
* Mon Feb 23 2015 hrvoje.senjan@gmail.com
- Update to 0.5
  * Trojitá can now be invoked with a mailto: URL (RFC 6068) on the
    command line for composing a new email.
  * Messages can be forwarded as attachments (support for inline
    forwarding is planned).
  * Passwords can be remembered in a secure, encrypted storage
    via QtKeychain.
  * E-mails with attachments are decorated with a paperclip
    icon in the overview.
  * Better rendering of e-mails with extraordinary MIME structure.
  * By default, only one instance is kept running, and can be
    controlled via D-Bus.
  * Trojitá now provides better error reporting, and can reconnect
    on network failures automatically.
  * The network state (Offline, Expensive Connection or Free Access)
    will be remembered across sessions.
  * When replying, it is now possible to retroactively change the
    reply type (Private Reply, Reply to All but Me, Reply to All,
    Reply to Mailing List, Handpicked).
  * When searching in a message, Trojitá will scroll to
    the current match.
  * Attachment preview for quick access to the enclosed files.
  * The mark-message-read-after-X-seconds setting is
    now configurable.
  * The IMAP refresh interval is now configurable.
  * Speed and memory consumption improvements.
  * Miscellaneous IMAP improvements.
  * Various fixes and improvements.
- Drop 0001-Explicitly-mark-libs-as-STATIC-to-not-allow-cmake-ru.patch,
  merged upstream
- Bump Qt BuildRequires to 5.2
* Fri Nov 28 2014 tchvatal@suse.com
- Add libqt5-sql-sqlite to BuildRequires too
* Mon Apr 28 2014 hrvoje.senjan@gmail.com
- Swap libQt5Sql5-sqlite to libqt5-sql-sqlite, as the latter is
  available also in 13.1 release
* Thu Mar 20 2014 hrvoje.senjan@gmail.com
- Update to 0.4.1
  * Fix for CVE-2014-2567
* Fri Mar 14 2014 tchvatal@suse.com
- Require sqlite backend for qtsql as we use just that one.
* Wed Mar  5 2014 tchvatal@suse.com
- Sort out the shared libs with patch rather than overriding rules.
  * 0001-Explicitly-mark-libs-as-STATIC-to-not-allow-cmake-ru.patch
* Wed Mar  5 2014 tchvatal@suse.com
- Enforce static libs as the switch in macro is wrong for us.
  Build system states them to be possible shared but in reality
  they are not.
- Fix license to BSD-3-Clause afaik it is the correct one here.
* Wed Mar  5 2014 tchvatal@suse.com
- Initial tweaked commit from home:jkt-gentoo:trojita so we only
  have the opensuse version here for better readability.
- Version 0.4
